# -*- coding: utf-8; -*-
#
# (c) 2004-2007 Linbox / Free&ALter Soft, http://linbox.com
# (c) 2007-2010 Mandriva, http://www.mandriva.com
#
# $Id$
#
# This file is part of Mandriva Management Console (MMC).
#
# MMC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# MMC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with MMC.  If not, see <http://www.gnu.org/licenses/>.

"""
MDS http plugin for the MMC agent.
"""
from datetime import datetime
import os
import shutil
import re
import logging
from mmc.support import mmctools
from mmc.support.config import PluginConfig, ConfigException
from ConfigParser import NoSectionError, NoOptionError
from mmc.core.audit import AuditFactory as AF
from mmc.plugins.apache.audit import AT, AA, PLUGIN_NAME
from mmc.plugins.apache import httpdb
from mmc.plugins.samba4 import addShare
from mmc.plugins.samba4 import deleteShare
from mmc.core.version import scmRevision

VERSION = "0.6.2"
APIVERSION = "1:1:0"
REVISION = scmRevision("$Rev$")

def getVersion(): return VERSION
def getApiVersion(): return APIVERSION
def getRevision(): return REVISION

def activate():
    """
     this function define if the module "http" can be activated.
     @return: return True if this module can be activate
     @rtype: boolean
    """
    config = HttpConfig("apache")
    logger = logging.getLogger()
    if config.disabled:
        msg = "disabled by configuration"
        logger.warning("Plugin http: " + msg + ".")
        return False
    result = True
    msg = ""
    try:
        config.check()
    except ConfigException, ce:
        msg = str(ce)
        result = False
    except Exception, e:
        msg = str(e)
        result = False
    if not result:
        logger.warning("Plugin http: " + msg + ".")
    return result

def getHttpConfig():
    return ManageHttp().getHttpConfig()

def getHttpModules():
    return ManageHttp().getHttpModules()

def get_list(list):
    return ManageHttp().get_list(list)

def setHttpConfig(domainname, port, docroot, emailadm, loglevel):
    return ManageHttp().setHttpConfig(domainname, port, docroot, emailadm, loglevel)

def setVirtualHost(fqdn, ssl, adminuser, share, email, desc, certificatefile, certificatekey, certificateca, ssldefault):
    return ManageHttp().setVirtualHost(fqdn, ssl, adminuser, share, email, desc, certificatefile, certificatekey, certificateca, ssldefault)

def delVirtualElement(elt, rmdir):
    return ManageHttp().delVirtualElement(elt, rmdir)

def changeState(elt):
    return ManageHttp().changeState(elt)

def addVirtualElement(elt):
    return ManageHttp().addVirtualElement(elt)

def reloadtHttp():
    return ManageHttp().reloadtHttp()


class HttpConfig(PluginConfig):
    def readConf(self):
        PluginConfig.readConf(self)

        # This MUST exists!
        self.SSLCertificateFilePath = self.get("openssl", "SSLCertificateFilePath")
        self.SSLCertificateKeyPath = self.get("openssl", "SSLCertificateKeyPath")
        self.CACertificatePath = self.get("openssl", "CACertificatePath")
        self.httpConfig = self.get("http", "httpConfig")
        self.httpConfigTemplate = self.get("http", "httpConfigTemplate")
        self.vhostIndexTemplate = self.get("http", "vhostIndexTemplate")
        self.webroot = self.get("http", "webroot")
        self.httpDb = self.get("http", "httpDb")
        self.vhostDir = self.get("http", "vhostDir")
        self.rootDomains = self.get("http", "rootDomains")

        try: self.httpdInit = self.get("http", "httpdInit")
        except (NoSectionError, NoOptionError): self.httpdInit = "/etc/init.d/httpd"

        try: self.httpdPid = self.get("http", "httpdPid")
        except (NoSectionError, NoOptionError): self.httpdPid = "/var/run/httpd.pid"

    def setDefault(self):
        PluginConfig.setDefault(self)

    def check(self):
        if not os.path.exists(self.httpConfig):
            raise ConfigException("Can't find httpd configuration file : %s" % self.httpConfig)
       
        if not os.path.exists(self.httpDb):
            httpdb.Base.metadata.create_all(httpdb.engine)

####################################################################
#           Class to persist and manipulate httpd files
####################################################################

class ManageHttp(object):
    def __init__(self):
        """
        For easier modification Arrays are always loaded
        """
        self.config = HttpConfig("apache")
        self.querys = {
            'vhost': List(httpdb.Vhosts.domain),
            'vssl': List(httpdb.Vhosts.ssl),
            'vsmb': List(httpdb.Vhosts.smbshare),
            'vdate': List(httpdb.Vhosts.date),
            'vdocroot': List(httpdb.Vhosts.docroot),
            'vstate': List(httpdb.Vhosts.state),
        }
        self.httpConfig = self.config.httpConfig
        self.httpDb = self.config.httpDb
        self.webroot = self.config.webroot
        self.vhostDir = self.config.vhostDir
        self.rootDomains = self.config.rootDomains
        self.httpdPid = self.config.httpdPid
        self.httpdInit = self.config.httpdInit
        self.SSLCertificateFilePath = self.config.SSLCertificateFilePath
        self.SSLCertificateKeyPath = self.config.SSLCertificateKeyPath
        self.CACertificatePath = self.config.CACertificatePath

        """Array to Manipulate httpd.conf"""
        self.contentArrC = []
        self.contentArrM = []
        arrTmp = []
        filter = ["Listen", "ServerName", "DocumentRoot", "ServerAdmin", "LogLevel"]
        httpconf = open(self.config.httpConfig)
        for row in httpconf:
            row = row.strip()
            arrTmp.append(row)
        httpconf.close()

        for f in filter:
            for i in range(1, arrTmp.__len__()):
                if(re.match('^' + f + ' .+', arrTmp[i])):
                    r = re.match('^' + f + ' .+', arrTmp[i])
                    self.contentArrC.append(r.group())

        for i in range(1, arrTmp.__len__()):
            if(re.match('^LoadModule \w+', arrTmp[i])):
                r = re.match('^LoadModule \w+', arrTmp[i])
                self.contentArrM.append(r.group())

    # This substitue an array of tuples in a file:
    # data ex: [("@EADM@", "admin@admin.com"),("@DOCROOT@", "/root/")]
    def substitution(self, data, source):
        f = open(source, 'r')
        filedata = f.read()
        f.close()

        for tup in data:
            filedata = filedata.replace(tup[0], tup[1])

        f = open(source, 'w')
        f.write(filedata)
        f.close()

    def setHttpConfig(self, domainname, port, docroot, emailadm, loglevel):
        # Clean teh old file
        if os.path.exists(self.config.httpConfig):
            os.remove(self.config.httpConfig)

        # Copy a new template
        shutil.copyfile(self.config.httpConfigTemplate, self.config.httpConfig)
        
        # Write the new data on the template
        data = []
        data.append(("@DM@", domainname))
        data.append(("@PT@", port))
        data.append(("@DOCROOT@", docroot))
        data.append(("@EADM@", emailadm))
        data.append(("@LL@", loglevel))
        self.substitution(data, self.config.httpConfig)
        
        # set up the default host to point to main page in docroot, if a vdomain do not exists or is disabled it will go to main domain page
        if(os.path.isfile(self.config.vhostDir + "00_default_vhosts.conf")):
            f = open(self.config.vhostDir + "00_default_vhosts.conf", "a")
        else:
            f = open(self.config.vhostDir + "00_default_vhosts.conf", "w")
        f.write("<VirtualHost *:80>" + '\n')
        f.write("ServerName " + domainname + '\n')
        f.write("ServerAlias www." + domainname + '\n')
        f.write("ServerAdmin " + emailadm + '\n')
        f.write("DirectoryIndex index.php index.html" + '\n')
        f.write("ErrorLog /var/log/httpd/" + domainname + "-error.log." + '\n')
        f.write("CustomLog /var/log/httpd/" + domainname + "-accesslog. combined" + '\n')
        f.write("<Directory " + docroot + ">" + '\n')
        f.write("                Options -Indexes +FollowSymLinks" + '\n')
        f.write("                 AllowOverride Options" + '\n')
        f.write("                 Order allow,deny" + '\n')
        f.write("                Allow from all" + '\n')
        f.write("</Directory>" + '\n')
        f.write("</VirtualHost>" + '\n')
        f.close()
        self.reloadtHttp()

    def setVirtualHost(self, fqdn, ssl, adminuser, share, email, desc, certificatefile, certificatekey, certificateca, ssldefault):
        if not (os.path.isdir(self.config.rootDomains)):
            os.mkdir(self.config.rootDomains, 0755)
         
        if(share == "on"):
            name = fqdn
            path = self.config.rootDomains + fqdn
            comment = desc
            usergroups = ""
            users = adminuser
            permAll = False
            browseable = True
            addShare(name, path, comment, browseable, permAll, usergroups, users)
        else:
            os.mkdir(self.config.rootDomains + fqdn, 0755)
        
        mmctools.shlaunch("touch " + self.config.vhostDir + fqdn + ".conf")
        alias = fqdn.split(".")
        f = open(self.config.vhostDir + fqdn + ".conf", 'w')
        f.write("Alias /" + alias[0] + " " + self.config.rootDomains + fqdn + '\n')
        f.write("<VirtualHost *:80>" + '\n')
        f.write("ServerName " + fqdn + '\n')
        if(ssl == "on"):
            f.write("RedirectMatch (/.*)$ https://" + fqdn + "/\n")
        f.write("ServerAlias www." + fqdn + '\n')
        f.write("ServerAdmin " + email + '\n')
        f.write("DirectoryIndex index.php index.html" + '\n')
        f.write("DocumentRoot " + self.config.rootDomains + fqdn + '\n')
        f.write("ErrorLog /var/log/httpd/" + fqdn + "-error.log." + '\n')
        f.write("CustomLog /var/log/httpd/" + fqdn + "-accesslog. combined" + '\n')
        f.write("<Directory " + self.config.rootDomains + fqdn + ">" + '\n')
        f.write("                Options -Indexes +FollowSymLinks" + '\n')
        f.write("                 AllowOverride Options" + '\n')
        f.write("                 Order allow,deny" + '\n')
        f.write("                Allow from all" + '\n')
        f.write("</Directory>" + '\n')
        f.write("</VirtualHost>" + '\n')
        f.close()

        # Copy a new index template
        shutil.copyfile(self.config.vhostIndexTemplate, self.config.rootDomains + fqdn + "/index.html")
        
        # Write the new data on the template
        data = []
        data.append(("@FQDN@", fqdn))
        self.substitution(data, self.config.rootDomains + fqdn + "/index.html")

        # Set permissions (FIXME)
        mmctools.shlaunch("chmod 755 -R " + self.config.rootDomains)
        mmctools.shlaunch("chown apache:apache -R " + self.config.rootDomains)
        
        for user in adminuser:
            mmctools.shlaunch("setfacl -m u:%s:rwx %s" % (str(user), self.config.rootDomains + fqdn))

        f = open("/etc/hosts", 'a')
        f.write('127.0.0.1        ' + fqdn + ' www.' + fqdn + '\n')
        f.close()

        if(ssl == "on"):
            if(certificatefile):
                shutil.move("/tmp/" + certificatefile, self.config.SSLCertificateFilePath + fqdn + ".crt")
            if(certificatekey):
                shutil.move("/tmp/" + certificatekey, self.config.SSLCertificateKeyPath + fqdn + ".key")
            if(certificateca):
                shutil.move("/tmp/" + certificateca, self.config.CACertificatePath + fqdn + ".pem")

            mmctools.shlaunch("touch " + self.config.vhostDir + fqdn + "_ssl.conf")

            f = open(self.config.vhostDir + fqdn + "_ssl.conf", 'w')
            f.write("NameVirtualHost *:443\n")
            f.write("<VirtualHost *:443>\n")
            f.write("ServerName %s\n" % fqdn)
            f.write("SSLEngine on\n")
            f.write("SSLCipherSuite HIGH:MEDIUM:!aNULL:!MD5\n")
            f.write("SSLProtocol all -SSLv2\n")
            if(certificatefile):
                f.write("SSLCertificateFile " + self.config.SSLCertificateFilePath + "%s.crt\n" % fqdn)
            else:
                f.write("SSLCertificateFile " + self.config.SSLCertificateFilePath + "localhost.crt\n")
            if(certificatekey):
                f.write("SSLCertificateKeyFile " + self.config.SSLCertificateKeyPath + "%s.key\n" % fqdn)
            else:
                f.write("SSLCertificateKeyFile " + self.config.SSLCertificateKeyPath + "localhost.key\n")
            f.write("DirectoryIndex index.php index.html\n")
            f.write("<Directory " + self.config.rootDomains + fqdn + ">" + '\n')
            f.write("    Options -Indexes FollowSymLinks MultiViews\n")
            f.write("    AllowOverride None\n")
            f.write("    Order allow,deny\n")
            f.write("    allow from all\n")
            f.write("    AllowOverride None\n")
            f.write("</Directory>\n")
            f.write("DocumentRoot " + self.config.rootDomains + fqdn + "" + '\n')
            f.write("ErrorLog /var/log/httpd/" + fqdn + "-error.log" + '\n')
            f.write("CustomLog /var/log/httpd/" + fqdn + "-ssl_requestlog combined" + '\n')
            f.write("</VirtualHost>\n")
            f.close()

        date = datetime.now()

        if(adminuser == ""):
            adminuser = "null"

        if(share == ""):
            share = "disabled"

        if(ssl == ""):
            ssl = "disabled"

        self.reloadtHttp()
        session = httpdb.Session()
        session.add(httpdb.Vhosts(fqdn, ssl, share, email, self.config.rootDomains + fqdn, date, "enable", ssldefault))
        session.commit()
   
    def reloadtHttp(self):
        try:
            from mmc.plugins.services.manager import ServiceManager
            ServiceManager().reload("httpd")
        except ImportError:
            from mmc.support.mmctools import ServiceManager
            SM = ServiceManager(self.httpdInit, self.httpdPid)
            SM.reload()

    def getHttpConfig(self):
        ret = self.contentArrC[:]
        return ret

    def getHttpModules(self):
        ret = self.contentArrM[:]
        return ret

    def get_list(self, list):
        return self.querys[list].get_list()

    def delVirtualElement(self, elt, rmdir):
        r = AF().log(PLUGIN_NAME, AA.HTTP_DEL_VIRTUAL_DOMAIN, [(elt, AT.AUDITLIST)])
        session = httpdb.Session()
        arr = []
        vhost = session.query(httpdb.Vhosts).filter(httpdb.Vhosts.domain == elt).first()
        if vhost.state == "enable":
            os.remove(self.config.vhostDir + elt + ".conf")
        else:
            os.remove(self.config.vhostDir + elt + ".conf.off")
        if vhost.state == "enable" and vhost.ssl == "on":
            os.remove(self.config.vhostDir + elt + "_ssl.conf")
        if vhost.state == "disable" and vhost.ssl == "on":
            os.remove(self.config.vhostDir + elt + "_ssl.conf.off")
        if vhost.ssl == "on" and vhost.ssldefault == "disable":
            os.remove(self.config.SSLCertificateFilePath + elt + ".crt")
            os.remove(self.config.SSLCertificateKeyPath + elt + ".key")
        if rmdir != "" and vhost.smbshare == "on":
            deleteShare(vhost.domain, self.config.webroot + elt)
        elif rmdir != "":
            shutil.rmtree(self.config.webroot + elt)
        domainname = elt.split('.')
        
        f = open("/etc/hosts")
        for row in f:
            if domainname[0] not in row:
                arr.append(row)
        f.close()
        f = open("/etc/hosts", 'w')
        for line in arr:
            f.write(line)
        f.close()
        session.delete(vhost)
        session.commit()
        self.reloadtHttp()
        r.commit()

    def changeState(self, elt):
        session = httpdb.Session()
        vhost = session.query(httpdb.Vhosts).filter(httpdb.Vhosts.domain == elt).first()
        if vhost.state == "enable":
            shutil.move(self.config.vhostDir + elt + ".conf", self.config.vhostDir + elt + ".conf.off")
            if vhost.ssl == "on":
                shutil.move(self.config.vhostDir + elt + "_ssl.conf", self.config.vhostDir + elt + "_ssl.conf.off")
            vhost.state = "disable"
            session.add(vhost)
            session.commit()
        else:
            shutil.move(self.config.vhostDir + elt + ".conf.off", self.config.vhostDir + elt + ".conf")
            if vhost.ssl == "on":
                shutil.move(self.config.vhostDir + elt + "_ssl.conf.off", self.config.vhostDir + elt + "_ssl.conf")
            vhost.state = "enable"
            session.add(vhost)
            session.commit()
        self.reloadtHttp()


class List(object):

    def __init__(self, sqlquery):
        self.query = sqlquery
        self.list = []
        self.read()

    def read(self):
        session = httpdb.Session()
        data = session.query(self.query).all()
        for row in data:
            self.list.append(str(row[0]))

    def get_list(self):
        return self.list
